function result = jerk(ti, tf, ai, af)
% calculate jerk using the change in acceleration and the change in time
%
% consumes: ti       initial time (seconds)
%           ai       initial acceleration (meters per second per second)
%           tf       final time (seconds)
%           af       final acceleration (meters per second per second)
%
% produces: result, jerk 
%
%
% examples:
%       >>  jerk(0,1,0,10)
%       ans =
%            10
%       >>  jerk(0,5,10,50)
%       ans =
%            8
%       >>   
%  D. Pavlick for CISC106, Sect 80, 10/01/2007

result = (af - ai)/(tf - ti);

return;
end

